@@ -32,10 +32,10 @@ class Python2Backend : public PythonBackend
     Cantor::Session* createSession();
 
     QString id() const;
-    KUrl helpUrl() const;
+    QUrl helpUrl() const;
     QString description() const;
 
     KConfigSkeleton* config() const;
 };
 
-#endif
\ No newline at end of file
+#endif
