@@ -36,9 +36,7 @@ static const char version[] = "0.6";
 int main(int argc, char **argv)
 {
     QApplication app(argc, argv);
-
-    // TODO: for >=KF5.15 use KCrash::initialize();
-    KCrash::setCrashHandler(KCrash::defaultCrashHandler);
+    KCrash::initialize();
 
     // Migrating configuration from 4.x applications to KF5-based applications
     QStringList configFiles;
@@ -72,15 +70,16 @@ int main(int argc, char **argv)
                      QLatin1String(version),
                      i18n(description),
                      KAboutLicense::GPL,
-                     i18n("(C) 2009-2015 Alexander Rieder"),
+                     i18n("(C) 2016 Filipe Saraiva<br/>(C) 2009-2015 Alexander Rieder"),
                      QString(),
                      QLatin1String("http://edu.kde.org/cantor"));
 
-    about.addAuthor( i18n("Alexander Rieder"), QString(), QLatin1String("alexanderrieder@gmail.com") );
+    about.addAuthor( i18n("Filipe Saraiva"), i18n("Maintainer<br/>Qt5/KF5 port, Scilab and Python backends"), QLatin1String("filipe@kde.org"),
+                     QLatin1String("http://filipesaraiva.info/") );
+    about.addAuthor( i18n("Alexander Rieder"), i18n("Original author<br/>Maintainer (2009 - 2015)"), QLatin1String("alexanderrieder@gmail.com") );
     about.addAuthor( i18n("Aleix Pol Gonzalez"), i18n("KAlgebra backend"), QLatin1String("aleixpol@kde.org") );
     about.addAuthor( i18n("Miha Čančula"), i18n("Octave backend"), QLatin1String("miha.cancula@gmail.com") );
-    about.addAuthor( i18n("Filipe Saraiva"), i18n("Scilab and Python backends"), QLatin1String("filipe@kde.org"),
-                     QLatin1String("http://filipesaraiva.info/") );
+
     about.addAuthor( i18n("Martin Küttler"), i18n("Interface"), QLatin1String("martin.kuettler@gmail.com") );
 
     about.addCredit(QLatin1String("Andreas Kainz"), i18n("Cantor icon"), QLatin1String("kainz.a@gmail.com"));
